Attacks
=======

This module contains implementations and wrappers for various adversarial attacks.

Preconfigured Attacks
---------------------

.. automodule:: attackbench.preconfigured
   :members:
   :undoc-members:
   :show-inheritance:

Attack Loading
--------------

.. automodule:: attackbench.attacks.registry
   :members:
   :undoc-members:
   :show-inheritance:

BoMN (Best-of-MinNorm)
----------------------

.. automodule:: attackbench.attacks.bomn
   :members:
   :undoc-members:
   :show-inheritance:

Custom Attacks
--------------

.. automodule:: attackbench.custom_components
   :members:
   :undoc-members:
   :show-inheritance:
